aboutsummaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorJohn Newbery <john@johnnewbery.com>2019-09-13 22:31:11 +0300
committerJohn Newbery <john@johnnewbery.com>2019-09-13 22:33:46 +0300
commit7dee8f48088c75ab0e51be60679505f8ce570919 (patch)
treecc31c38c3d8aaf300645db7e84ddb877b5e89fcd /test
parentfb4f5beb6ede4aadeaff779cd67a0f6665419488 (diff)
downloadbitcoin-7dee8f48088c75ab0e51be60679505f8ce570919.tar.xz
[wallet] Rename 'decode' argument in gettransaction method to 'verbose'
This makes the RPC method consistent with other RPC methods that have a 'verbose' option. Change the name of the return object from 'decoded' to details. Update help text.
Diffstat (limited to 'test')
-rwxr-xr-xtest/functional/wallet_basic.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/functional/wallet_basic.py b/test/functional/wallet_basic.py
index 74350649c7..4c3fe3078b 100755
--- a/test/functional/wallet_basic.py
+++ b/test/functional/wallet_basic.py
@@ -499,10 +499,10 @@ class WalletTest(BitcoinTestFramework):
self.nodes[0].setlabel(change, 'foobar')
assert_equal(self.nodes[0].getaddressinfo(change)['ischange'], False)
- # Test "decoded" field value in gettransaction response
- self.log.info("Testing gettransaction decoding...")
- tx = self.nodes[0].gettransaction(txid=txid, decode=True)
- assert_equal(tx["decoded"], self.nodes[0].decoderawtransaction(tx["hex"]))
+ # Test "verbose" field value in gettransaction response
+ self.log.info("Testing verbose gettransaction...")
+ tx = self.nodes[0].gettransaction(txid=txid, verbose=True)
+ assert_equal(tx["details"], self.nodes[0].decoderawtransaction(tx["hex"]))
if __name__ == '__main__':